@@ -2,7 +2,7 @@
 
 /*  version.c -- report version numbers for plugins.
 
-    Copyright (C) 2014-2021 Genome Research Ltd.
+    Copyright (C) 2014-2023 Genome Research Ltd.
 
     Author: Petr Danecek <pd3@sanger.ac.uk>
 
@@ -74,22 +74,26 @@ const char *hts_bcf_wmode(int file_type)
 const char *hts_bcf_wmode2(int file_type, const char *fname)
 {
     if ( !fname ) return hts_bcf_wmode(file_type);
-    int len = strlen(fname);
-    if ( len >= 4 && !strcasecmp(".bcf",fname+len-4) ) return hts_bcf_wmode(FT_BCF|FT_GZ);
-    if ( len >= 4 && !strcasecmp(".vcf",fname+len-4) ) return hts_bcf_wmode(FT_VCF);
-    if ( len >= 7 && !strcasecmp(".vcf.gz",fname+len-7) ) return hts_bcf_wmode(FT_VCF|FT_GZ);
-    if ( len >= 8 && !strcasecmp(".vcf.bgz",fname+len-8) ) return hts_bcf_wmode(FT_VCF|FT_GZ);
+    const char *end = fname ? strstr(fname, HTS_IDX_DELIM) : NULL;
+    if ( !end ) end = fname ? fname + strlen(fname) : fname;
+    int len = end - fname;
+    if ( len >= 4 && !strncasecmp(".bcf",fname+len-4,4) ) return hts_bcf_wmode(FT_BCF|FT_GZ);
+    if ( len >= 4 && !strncasecmp(".vcf",fname+len-4,4) ) return hts_bcf_wmode(FT_VCF);
+    if ( len >= 7 && !strncasecmp(".vcf.gz",fname+len-7,7) ) return hts_bcf_wmode(FT_VCF|FT_GZ);
+    if ( len >= 8 && !strncasecmp(".vcf.bgz",fname+len-8,8) ) return hts_bcf_wmode(FT_VCF|FT_GZ);
     return hts_bcf_wmode(file_type);
 }
 
 void set_wmode(char dst[8], int file_type, const char *fname, int clevel)
 {
     const char *ret = NULL;
-    int len = fname ? strlen(fname) : 0;
-    if ( len >= 4 && !strcasecmp(".bcf",fname+len-4) ) ret = hts_bcf_wmode(FT_BCF|FT_GZ);
-    else if ( len >= 4 && !strcasecmp(".vcf",fname+len-4) ) ret = hts_bcf_wmode(FT_VCF);
-    else if ( len >= 7 && !strcasecmp(".vcf.gz",fname+len-7) ) ret = hts_bcf_wmode(FT_VCF|FT_GZ);
-    else if ( len >= 8 && !strcasecmp(".vcf.bgz",fname+len-8) ) ret = hts_bcf_wmode(FT_VCF|FT_GZ);
+    const char *end = fname ? strstr(fname, HTS_IDX_DELIM) : NULL;
+    if ( !end ) end = fname ? fname + strlen(fname) : fname;
+    int len = end - fname;
+    if ( len >= 4 && !strncasecmp(".bcf",fname+len-4,4) ) ret = hts_bcf_wmode(FT_BCF|FT_GZ);
+    else if ( len >= 4 && !strncasecmp(".vcf",fname+len-4,4) ) ret = hts_bcf_wmode(FT_VCF);
+    else if ( len >= 7 && !strncasecmp(".vcf.gz",fname+len-7,7) ) ret = hts_bcf_wmode(FT_VCF|FT_GZ);
+    else if ( len >= 8 && !strncasecmp(".vcf.bgz",fname+len-8,8) ) ret = hts_bcf_wmode(FT_VCF|FT_GZ);
     else ret = hts_bcf_wmode(file_type);
     if ( clevel>=0 && clevel<=9 )
     {
@@ -109,3 +113,33 @@ int parse_overlap_option(const char *arg)
     else if ( strcasecmp(arg, "variant") == 0 || strcmp(arg, "2") == 0 ) return 2;
     else return -1;
 }
+
+// See also samtools/sam_utils.c auto_index()
+int init_index(htsFile *fh, bcf_hdr_t *hdr, char *fname, char **idx_fname)
+{
+    int min_shift = 14; // CSI
+
+    if ( !fname || !*fname || !strcmp(fname, "-") ) return -1;
+
+    char *delim = strstr(fname, HTS_IDX_DELIM);
+    if (delim)
+    {
+        delim += strlen(HTS_IDX_DELIM);
+        *idx_fname = strdup(delim);
+        if ( !*idx_fname ) return -1;
+
+        size_t l = strlen(*idx_fname);
+        if ( l >= 4 && strcmp(*idx_fname + l - 4, ".tbi")==0 ) min_shift = 0;
+    }
+    else
+    {
+        if ( !(*idx_fname = malloc(strlen(fname)+6)) ) return -1;
+        sprintf(*idx_fname, "%s.csi", fname);
+    }
+
+    if ( bcf_idx_init(fh, hdr, min_shift, *idx_fname) < 0 ) return -1;
+
+    return 0;
+}
+
+
