@@ -1,4 +1,3 @@
-import sys
 import os
 import glob
 import gzip
@@ -27,34 +26,20 @@ LINKDIR = os.path.abspath(os.path.join(
 TESTS_TEMPDIR = os.path.abspath(os.path.join(os.path.dirname(__file__), "tmp"))
 
 
-IS_PYTHON3 = sys.version_info[0] >= 3
+from itertools import zip_longest
+from urllib.request import urlopen
 
 
-if IS_PYTHON3:
-    from itertools import zip_longest
-    from urllib.request import urlopen
-else:
-    from itertools import izip as zip_longest
-    from urllib2 import urlopen
-
-
-if IS_PYTHON3:
-    def force_str(s):
-        try:
-            return s.decode('ascii')
-        except AttributeError:
-            return s
-
-    def force_bytes(s):
-        try:
-            return s.encode('ascii')
-        except AttributeError:
-            return s
-else:
-    def force_str(s):
+def force_str(s):
+    try:
+        return s.decode('ascii')
+    except AttributeError:
         return s
 
-    def force_bytes(s):
+def force_bytes(s):
+    try:
+        return s.encode('ascii')
+    except AttributeError:
         return s
 
 
